@@ -4,7 +4,7 @@ from .query import QueryHandler
 from .start import StartGroupHandler, StartHandler
 from .text import TextHandler
 from .update import UpdateHandler
-from .message_or_query import MessageOrQueryHandler
+
 __all__ = [
     "UpdateHandler",
     "MessageHandler",
@@ -13,5 +13,4 @@ __all__ = [
     "CommandHandler",
     "StartHandler",
     "StartGroupHandler",
-    "MessageOrQueryHandler",
 ]
