@@ -1,9 +1,7 @@
 from abc import ABC
 
-from botty_core.types import PTBHandler
-from telegram import ext
-
 from botty.keyboards import InlineKeyboard
+from botty.triggers import CommandTrigger
 
 from .text import TextHandler
 
@@ -15,8 +13,8 @@ class CommandHandler(TextHandler, ABC):
         reply_text: str | None = None,
         reply_keyboard: InlineKeyboard | None = None,
     ) -> None:
-        self.on_command = command
         super().__init__(reply_text, reply_keyboard)
+        self._command = command
 
-    def build(self) -> PTBHandler:
-        return ext.CommandHandler(self.on_command, self.handle, self.filters)
+    def get_trigger(self) -> CommandTrigger:
+        return CommandTrigger(self._command)
