@@ -1,8 +1,7 @@
 from abc import ABC
 
-from telegram import ext
-
 from botty.keyboards import InlineKeyboard
+from botty.triggers import StartGroupTrigger
 
 from .command import CommandHandler
 
@@ -17,4 +16,5 @@ class StartHandler(CommandHandler, ABC):
 
 
 class StartGroupHandler(StartHandler):
-    filters = StartHandler.filters & ext.filters.ChatType.GROUPS
+    def get_trigger(self) -> StartGroupTrigger:
+        return StartGroupTrigger()
